@@ -1,6 +1,7 @@
 package cli
 
 import (
+	"os"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -22,3 +23,21 @@ func TestAPIShow(t *testing.T) {
 	captured := runNoReset("api show test")
 	assert.Equal(t, captured, "\x1b[38;5;247m{\x1b[0m\n  \x1b[38;5;74m\"base\"\x1b[0m\x1b[38;5;247m:\x1b[0m \x1b[38;5;150m\"https://api.example.com\"\x1b[0m\n\x1b[38;5;247m}\x1b[0m\n")
 }
+
+func TestEditAPIsMissingEditor(t *testing.T) {
+	os.Setenv("EDITOR", "")
+	os.Setenv("VISUAL", "")
+	exited := false
+	editAPIs(func(code int) {
+		exited = true
+	})
+	assert.True(t, exited)
+}
+
+func TestEditBadCommand(t *testing.T) {
+	os.Setenv("EDITOR", "bad-command")
+	os.Setenv("VISUAL", "")
+	assert.Panics(t, func() {
+		editAPIs(func(code int) {})
+	})
+}
