@@ -8,10 +8,8 @@ import (
 	"net/http"
 	"net/url"
 	"os"
-	"path"
 	"path/filepath"
 	"regexp"
-	"runtime"
 	"runtime/debug"
 	"strings"
 	"time"
@@ -572,23 +570,50 @@ Not after (expires): %s (%s)
 }
 
 func userHomeDir() string {
-	if runtime.GOOS == "windows" {
-		home := os.Getenv("HOMEDRIVE") + os.Getenv("HOMEPATH")
-		if home == "" {
-			home = os.Getenv("USERPROFILE")
-		}
-		return home
+	home, err := os.UserHomeDir()
+	if err != nil {
+		panic("HOME directoy is not defined")
 	}
-	return os.Getenv("HOME")
+	return home
 }
 
 func getConfigDir(appName string) string {
 	configDirEnv := strings.ToUpper(appName) + "_CONFIG_DIR"
-
 	configDir := os.Getenv(configDirEnv)
 
 	if configDir == "" {
-		configDir = path.Join(userHomeDir(), "."+appName)
+		// Create new config directory
+		configBase, _ := os.UserConfigDir()
+		configDir = filepath.Join(configBase, appName)
+
+		// Check for legacy config dir
+		legacyConfigDir := filepath.Join(viper.GetString("home-directory"), "."+appName)
+		if _, err := os.Stat(legacyConfigDir); err == nil {
+			// Only migrate if the new config dir doesn't exist, so that this
+			// is a one-time operation. There are edge cases where configs could
+			// get lost if we migrate every time (e.g. running an old version
+			// that creates an empty ~/.restish/apis.json).
+			if _, err := os.Stat(configDir); err != nil {
+				// Define files to migrate
+				for _, filename := range []string{
+					"config.json",
+					"apis.json",
+					"cache.json",
+				} {
+					oldPath := filepath.Join(legacyConfigDir, filename)
+					newDir := configDir
+					if filename == "cache.json" {
+						newDir = getCacheDir()
+					}
+					if _, err := os.Stat(oldPath); err == nil {
+						os.MkdirAll(newDir, 0700)
+						os.Rename(oldPath, filepath.Join(newDir, filename))
+					}
+				}
+				// Everything else is a cache that can be regenerated
+				os.RemoveAll(legacyConfigDir)
+			}
+		}
 	}
 	return configDir
 }
@@ -600,14 +625,20 @@ func getCacheDir() string {
 	cacheDir := os.Getenv(cacheDirEnv)
 
 	if cacheDir == "" {
-		cacheDir = path.Join(userHomeDir(), "."+appName)
+		cache, _ := os.UserCacheDir()
+		cacheDir = filepath.Join(cache, appName)
 	}
 	return cacheDir
 }
 
 func initConfig(appName, envPrefix string) {
+	viper.Set("app-name", appName)
+
 	// One-time setup to ensure the path exists so we can write files into it
 	// later as needed.
+	home := userHomeDir()
+	viper.Set("home-directory", home)
+
 	configDir := getConfigDir(appName)
 	if err := os.MkdirAll(configDir, 0700); err != nil {
 		panic(err)
@@ -615,8 +646,9 @@ func initConfig(appName, envPrefix string) {
 
 	// Load configuration from file(s) if provided.
 	viper.SetConfigName("config")
-	viper.AddConfigPath("/etc/" + appName + "/")
-	viper.AddConfigPath("$HOME/." + appName + "/")
+	viper.AddConfigPath(filepath.Join("/etc/", appName))
+	viper.AddConfigPath(filepath.Join(viper.GetString("home-directory"), "."+appName))
+	viper.AddConfigPath(configDir)
 	viper.ReadInConfig()
 
 	// Load configuration from the environment if provided. Flags below get
@@ -626,7 +658,6 @@ func initConfig(appName, envPrefix string) {
 	viper.AutomaticEnv()
 
 	// Save a few things that will be useful elsewhere.
-	viper.Set("app-name", appName)
 	viper.Set("config-directory", configDir)
 	viper.SetDefault("server-index", 0)
 }
@@ -644,13 +675,13 @@ func initCache(appName string) {
 
 	// Write a blank cache if no file is already there. Later you can use
 	// cli.Cache.SaveConfig() to write new values.
-	filename := path.Join(cacheDir, "cache.json")
+	filename := filepath.Join(cacheDir, "cache.json")
 	if _, err := os.Stat(filename); os.IsNotExist(err) {
 		if err := os.WriteFile(filename, []byte("{}"), 0600); err != nil {
 			panic(err)
 		}
 	}
-
+	viper.Set("cache-dir", cacheDir)
 	Cache.ReadInConfig()
 }
 
@@ -658,6 +689,7 @@ func initCache(appName string) {
 // the CLI.
 func Defaults() {
 	// Register content encodings
+	AddEncoding("deflate", &DeflateEncoding{})
 	AddEncoding("gzip", &GzipEncoding{})
 	AddEncoding("br", &BrotliEncoding{})
 
@@ -670,6 +702,7 @@ func Defaults() {
 	AddContentType("text", "text/*", 0.2, &Text{})
 	AddContentType("table", "", -1, &Table{})
 	AddContentType("readable", "", -1, &Readable{})
+	AddContentType("gron", "", -1, &Gron{})
 
 	// Add link relation parsers
 	AddLinkParser(&LinkHeaderParser{})
